pub type SmallFutex = Atomic<u32>;Available on Linux, or Android, or Emscripten and target feature
atomics, or FreeBSD, or OpenBSD, or DragonFly BSD, or Fuchsia only.Expand description
An atomic for use as a futex that is at least 8-bits but may be larger.
Aliased Type
#[repr(C)]pub struct SmallFutex { /* private fields */ }